@@ -1,4 +1,4 @@
-"""The Wyoming protocol for Rhasspy."""
+"""Peer-to-peer protocol for voice assistants."""
 from .version import __version__
 
 __author__ = "Michael Hansen"
